@@ -168,7 +168,8 @@ class AccessControl(object):
             logging.info(dict(
                 action='with_permission', message=_('access denied'),
                 resource=self.resource, uid=self.uid, ident=self.identity,
-                access=access, rbac=rbac, duration='%.3f' % duration))
+                id=id, access=access, rbac=''.join(rbac),
+                duration='%.3f' % duration))
         return False
 
     def with_filter(self, query, access='r'):
@@ -227,6 +228,8 @@ class AccessControl(object):
         Returns:
           set: actions available to principal
         """
+        # logging.info(dict(step=3, owner_uid=owner_uid, membership=membership,
+        #                   id=id, privacy=privacy))
         if query:
             try:
                 record = query.one()
@@ -258,6 +261,10 @@ class AccessControl(object):
             except NoResultFound:
                 pass
 
+        # logging.info(dict(step=4, owner_uid=owner_uid, membership=membership,
+        #                   id=id, privacy=privacy, auth=self.auth,
+        #                   resource=self.resource))
+
         actions, defaults = (set(), set())
         if privacy == 'public' or (
                 self.auth and id and '%s-%s-%s' % (membership, id, privacy)
@@ -300,6 +307,7 @@ class AccessControl(object):
                               '%s:%s' % (self.resource, match_id))):
                         actions |= policy['actions']
         actions -= deny_delete
+        # logging.info(dict(step=5, id=id, actions=actions))
         return actions if len(actions) else defaults
 
     def apikey_create(self):
