@@ -3,4 +3,4 @@ from .local_user import LocalUser
 from .oauth2 import OAuth2
 from .totp import AuthTOTP
 
-__all__ = ('APIKey', 'AuthTOTP', 'LocalUser', 'OAuth2')
+__all__ = ('APIKey', 'AuthTOTP', 'LDAP', 'LocalUser', 'OAuth2')
