@@ -115,6 +115,7 @@ class BasicCRUD(object):
         grant = (self.resource if self.resource.endswith('s')
                  else self.resource + 's')
         limit = Grants().get(grant, uid=uid)
+        # TODO filter expired and disabled records
         if grant in ServiceConfig().config.DEFAULT_GRANTS and g.db.query(
                 self.model).filter_by(uid=uid).count() >= limit:
             msg = _('user limit exceeded')
@@ -203,7 +204,8 @@ class BasicCRUD(object):
                 ident=acc.identity, duration=utils.req_duration()))
             return retval, 200
         else:
-            return dict(message=_(u'access denied'), id=id), 403
+            return (dict(message=_(u'access denied'), id=id),
+                    403 if acc.auth else 401)
 
     @staticmethod
     def update(id, body, access='u', limit_related={}):
@@ -424,6 +426,7 @@ class BasicCRUD(object):
         except Exception as ex:
             return db_abort(str(ex), **logmsg)
         count = 0
+        # logging.info(dict(step=1, membership=acc.primary_resource, **logmsg))
         for result in results[:limit]:
             record = result.as_dict()
             if hasattr(self.model, 'owner'):
@@ -432,6 +435,8 @@ class BasicCRUD(object):
             if record.get('category_id'):
                 record['category'] = result.category.name
             # TODO - takes 30ms per record for rbac: optimize or redesign
+            # logging.info(dict(step=2, id=record.get('id'),
+            #     privacy=record.get('privacy')))
             record['rbac'] = ''.join(sorted(list(
                 acc.rbac_permissions(owner_uid=record.get('uid'),
                                      membership=acc.primary_resource,
